/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.system.graph.component;

import org.wamblee.system.core.Component;
import org.wamblee.system.core.RequiredInterface;
import org.wamblee.system.graph.Node;

/**
 * Required interface node.
 * 
 * @author Erik Brakkee
 */
public class RequiredInterfaceNode implements Node {
    private Component component;

    private RequiredInterface required;

    /**
     * Creates a new RequiredInterfaceNode object.
     * 
     */
    public RequiredInterfaceNode(Component aComponent,
        RequiredInterface aRequired) {
        component = aComponent;
        required = aRequired;
    }

    @Override
    public String getName() {
        return component.getQualifiedName() + ":" + required.getName();
    }

    public RequiredInterface getRequired() {
        return required;
    }

    public Component getComponent() {
        return component;
    }

    @Override
    public String toString() {
        return component.getQualifiedName() + ":" + required;
    }
}
